@@ -11,26 +11,30 @@
 #' use_git()
 #' }
 use_git <- function(message = "Initial commit") {
-  if (uses_git()) {
-    return(invisible())
+  needs_init <- !uses_git()
+  if (needs_init) {
+    ui_done("Initialising Git repo")
+    git_init()
   }
 
-  ui_done("Initialising Git repo")
-  git_init()
-
   use_git_ignore(c(".Rhistory", ".RData", ".Rproj.user"))
-  git_ask_commit(message)
+  if (git_uncommitted(untracked = TRUE)) {
+    git_ask_commit(message, untracked = TRUE)
+  }
+
+  if (needs_init) {
+    restart_rstudio("A restart of RStudio is required to activate the Git pane")
+  }
 
-  restart_rstudio("A restart of RStudio is required to activate the Git pane")
   invisible(TRUE)
 }
 
-git_ask_commit <- function(message) {
-  if (!interactive()) {
+git_ask_commit <- function(message, untracked = FALSE) {
+  if (!is_interactive() || !uses_git()) {
     return(invisible())
   }
 
-  paths <- unlist(git_status(), use.names = FALSE)
+  paths <- unlist(git_status(untracked = untracked), use.names = FALSE)
   if (length(paths) == 0) {
     return(invisible())
   }
@@ -49,15 +53,24 @@ git_ask_commit <- function(message) {
   ))
 
   if (ui_yeah("Is it ok to commit them?")) {
-    ui_done("Adding files")
-    repo <- git_repo()
-    git2r::add(repo, paths)
-    ui_done("Commit with message {ui_value(message)}")
-    git2r::commit(repo, message)
+    git_commit(paths, message)
   }
   invisible()
 }
 
+git_commit <- function(paths, message) {
+  ui_done("Adding files")
+  repo <- git_repo()
+  git2r::add(repo, paths)
+  ui_done("Commit with message {ui_value(message)}")
+  git2r::commit(repo, message)
+  rstudio_git_tickle()
+}
+
+git_has_commits <- function() {
+  length(git2r::commits(n = 1, repo = git_repo())) > 0
+}
+
 #' Add a git hook
 #'
 #' Sets up a git hook using specified script. Creates hook directory if
@@ -90,6 +103,7 @@ use_git_hook <- function(hook, script) {
 #' @export
 use_git_ignore <- function(ignores, directory = ".") {
   write_union(proj_path(directory, ".gitignore"), ignores)
+  rstudio_git_tickle()
 }
 
 #' Configure Git
@@ -168,7 +182,7 @@ use_git_config <- function(scope = c("user", "project"), ...) {
 git_protocol <- function() {
   protocol <- getOption(
     "usethis.protocol",
-    default = if (interactive()) NA else "ssh"
+    default = if (is_interactive()) NA else "ssh"
   )
 
   ## this is where a user-supplied protocol gets checked, because
@@ -213,8 +227,7 @@ use_git_protocol <- function(protocol) {
 }
 
 choose_protocol <- function() {
-  ## intercept with our internal interactive()
-  if (!interactive()) {
+  if (!is_interactive()) {
     return(invisible())
   }
   choices <- c(
@@ -291,7 +304,7 @@ choose_protocol <- function() {
 use_git_remote <- function(name = "origin", url, overwrite = FALSE) {
   stopifnot(is_string(name))
   stopifnot(is.null(url) || is_string(url))
-  stopifnot(rlang::is_true(overwrite) || rlang::is_false(overwrite))
+  stopifnot(is_true(overwrite) || is_false(overwrite))
 
   repo <- git_repo()
   remotes <- git_remotes()
@@ -326,7 +339,7 @@ git_remotes <- function() {
 }
 
 git2r_env <- new.env(parent = emptyenv())
-have_git2r_credentials <- function() rlang::env_has(git2r_env, "credentials")
+have_git2r_credentials <- function() env_has(git2r_env, "credentials")
 
 #' Produce or register git credentials
 #'
@@ -349,23 +362,23 @@ have_git2r_credentials <- function() rlang::env_has(git2r_env, "credentials")
 #'
 #' @section SSH credentials:
 #'
-#'   For `protocol = "ssh"`, by default, usethis passes `NULL` credentials
-#'   to git2r. This will work if you have the exact configuration expected by
-#'   git2r:
-#'     1. Your public and private keys are in the default locations,
-#'     `~/.ssh/id_rsa.pub` and `~/.ssh/id_rsa`, respectively.
-#'     1. All the relevant software agrees on the definition of `~/`, i.e.
-#'     your home directory. This is harder than it sounds on Windows.
-#'     1. Your `ssh-agent` is configured to manage your SSH passphrase, if you
-#'     have one. This too can be a problem on Windows.
-#'   Read more about SSH setup in [Happy
-#'   Git](http://happygitwithr.com/ssh-keys.html), especially the
-#'   [troubleshooting
-#'   section](http://happygitwithr.com/ssh-keys.html#ssh-troubleshooting).
+#' For `protocol = "ssh"`, by default, usethis passes `NULL` credentials
+#' to git2r. This will work if you have the exact configuration expected by
+#' git2r:
 #'
-#'   If the `NULL` default doesn't work, you can make `credentials` explicitly
-#'   with [git2r::cred_ssh_key()] and register that with
-#'   `use_git_credentials()` for the rest of the session:
+#' 1. Your public and private keys are in the default locations,
+#' `~/.ssh/id_rsa.pub` and `~/.ssh/id_rsa`, respectively.
+#' 1. All the relevant software agrees on the definition of `~/`, i.e.
+#' your home directory. This is harder than it sounds on Windows.
+#' 1. Your `ssh-agent` is configured to manage your SSH passphrase, if you have
+#' one. This too can be a problem on Windows. Read more about SSH setup in
+#' [Happy Git and GitHub for the useR](https://happygitwithr.com/ssh-keys.html),
+#' especially the [troubleshooting
+#' section](https://happygitwithr.com/ssh-keys.html#ssh-troubleshooting).
+#'
+#' If the `NULL` default doesn't work, you can make `credentials` explicitly
+#' with [git2r::cred_ssh_key()] and register that with
+#' `use_git_credentials()` for the rest of the session:
 #' ```
 #' my_cred <- git2r::cred_ssh_key(
 #'    publickey  = "path/to/your/id_rsa.pub",
@@ -375,8 +388,8 @@ have_git2r_credentials <- function() rlang::env_has(git2r_env, "credentials")
 #' )
 #' use_git_credentials(credentials = my_cred)
 #' ```
-#'   For the remainder of the session, `git_credentials()` will return
-#'   `my_cred`.
+#' For the remainder of the session, `git_credentials()` will return
+#' `my_cred`.
 #'
 #' @section HTTPS credentials:
 #'
@@ -407,7 +420,7 @@ have_git2r_credentials <- function() rlang::env_has(git2r_env, "credentials")
 #'   [git2r::cred_env()], [git2r::cred_ssh_key()], [git2r::cred_token()], or
 #'   [git2r::cred_user_pass()].
 #'
-#' @return Either `NULL` or a git2r credential object, invisibly. I.e.,
+#' @return Either `NULL` or a git2r credential object, invisibly, i.e.
 #'   something to be passed to git2r as `credentials`.
 #' @export
 #'
@@ -447,14 +460,14 @@ use_git_credentials <- function(credentials) {
 #' git/GitHub sitrep
 #'
 #' Get a situation report on your current git/GitHub status. Useful for
-#' diagnosing problems.
-#'
+#' diagnosing problems. [git_vaccinate()] adds some basic R- and RStudio-related
+#' entries to the user-level git ignore file.
 #' @export
 #' @examples
 #' git_sitrep()
 git_sitrep <- function() {
-  # git user ------------------------------------------------------------------
-  hd_line("Git user")
+  # git global ----------------------------------------------------------------
+  hd_line("Git config (global)")
   kv_line("Name", git_config_get("user.name", global = TRUE))
   kv_line("Email", git_config_get("user.email", global = TRUE))
   ## TODO: forward info from the credentials package once we start using it
@@ -462,6 +475,16 @@ git_sitrep <- function() {
   ## e.g., git version, HTTPS credential helpers, SSH keys, etc.
   kv_line("Vaccinated", git_vaccinated())
 
+  # git project ---------------------------------------------------------------
+  if (proj_active() && uses_git()) {
+    local <- git2r::config(git_repo())$local
+    if (any(c("user.name", "user.email") %in% names(local))) {
+      hd_line("Git config (project)")
+      kv_line("Name", git_config_get("user.name"))
+      kv_line("Email", git_config_get("user.email"))
+    }
+  }
+
   # usethis + git2r ----------------------------------------------------------
   hd_line("usethis + git2r")
   kv_line("Default usethis protocol", getOption("usethis.protocol"))
@@ -478,14 +501,24 @@ git_sitrep <- function() {
   have_token <- have_github_token()
   if (have_token) {
     kv_line("Personal access token", "<found in env var>")
-    who <- github_user()
-    if (is.null(who)) {
-      ui_oops("Token is invalid.")
-      have_token <- FALSE
-    } else {
-      kv_line("User", who$login)
-      kv_line("Name", who$name)
-    }
+    tryCatch(
+      {
+        who <- gh::gh_whoami(github_token())
+        kv_line("User", who$login)
+        kv_line("Name", who$name)
+      },
+      http_error_401 = function(e) ui_oops("Token is invalid."),
+      error = function(e) ui_oops("Can't validate token. Is the network reachable?")
+    )
+    tryCatch(
+      {
+        emails <- unlist(gh::gh("/user/emails", .token = github_token()))
+        emails <- emails[names(emails) == "email"]
+        kv_line("Email(s)", emails)
+      },
+      http_error_404 = function(e) kv_line("Email(s)", "<unknown>"),
+      error = function(e) ui_oops("Can't validate token. Is the network reachable?")
+    )
   } else {
     kv_line("Personal access token", NULL)
   }
@@ -512,7 +545,7 @@ git_sitrep <- function() {
   ## TODO: rework when ui_*() functions make it possible to do better
   branch <- if (is.null(branch)) "<unset>" else branch
   tracking_branch <- if (is.null(tracking_branch)) "<unset>" else tracking_branch
-  cat_line("* ", "Local branch -> remote tracking branch: ",
+  ui_inform("* ", "Local branch -> remote tracking branch: ",
            ui_value(branch), " -> ", ui_value(tracking_branch))
 
   # PR outlook -------------------------------------------------------------
@@ -610,7 +643,7 @@ git_vaccinated <- function() {
     return(FALSE)
   }
 
-  lines <- readLines(path)
+  lines <- read_utf8(path)
   all(git_global_ignore %in% lines)
 }
 
