@@ -4,10 +4,10 @@
 #'
 #' @inheritParams use_template
 #' @seealso The [important files
-#'   section](http://r-pkgs.had.co.nz/release.html#important-files) of [R
-#'   Packages](http://r-pkgs.had.co.nz).
+#'   section](https://r-pkgs.org/release.html#important-files) of [R
+#'   Packages](https://r-pkgs.org).
 #' @export
-use_news_md <- function(open = interactive()) {
+use_news_md <- function(open = rlang::is_interactive()) {
   check_uncommitted_changes()
 
   use_template(
@@ -25,13 +25,21 @@ use_news_heading <- function(version) {
     return(invisible())
   }
 
-  news <- readLines(news_path, encoding = "UTF-8")
+  news <- read_utf8(news_path)
   title <- glue("# {project_name()} {version}")
 
   if (title == news[[1]]) {
     return(invisible())
   }
 
+  development_title <- glue("# {project_name()} (development version)")
+  if (development_title == news[[1]]) {
+    news[[1]] <- title
+
+    ui_done("Replacing development heading in NEWS.md")
+    return(write_utf8(news_path, news))
+  }
+
   ui_done("Adding new heading to NEWS.md")
   write_utf8(news_path, c(title, "", news))
 }
