@@ -16,19 +16,19 @@ if (!is.null(session_temp_proj)) {
   ))
 }
 
-scoped_temporary_package <- function(dir = file_temp(pattern = "testpkg"),
+create_local_package <- function(dir = file_temp(pattern = "testpkg"),
                                      env = parent.frame(),
                                      rstudio = FALSE) {
-  scoped_temporary_thing(dir, env, rstudio, "package")
+  create_local_thing(dir, env, rstudio, "package")
 }
 
-scoped_temporary_project <- function(dir = file_temp(pattern = "testproj"),
+create_local_project <- function(dir = file_temp(pattern = "testproj"),
                                      env = parent.frame(),
                                      rstudio = FALSE) {
-  scoped_temporary_thing(dir, env, rstudio, "project")
+  create_local_thing(dir, env, rstudio, "project")
 }
 
-scoped_temporary_thing <- function(dir = file_temp(pattern = pattern),
+create_local_thing <- function(dir = file_temp(pattern = pattern),
                                    env = parent.frame(),
                                    rstudio = FALSE,
                                    thing = c("package", "project")) {
@@ -38,25 +38,13 @@ scoped_temporary_thing <- function(dir = file_temp(pattern = pattern),
   }
 
   old_project <- proj_get_()
-  ## Can't schedule a deferred project reset if calling this from the R
-  ## console, which is useful when developing tests
-  if (identical(env, globalenv())) {
-    ui_done("Switching to a temporary project!")
-    if (!is.null(old_project)) {
-      command <- paste0('proj_set(\"', old_project, '\")')
-      ui_todo(
-        "Restore current project with: {ui_code(command)}"
-      )
-    }
-  } else {
-    withr::defer({
-      ui_silence({
-        proj_set(old_project, force = TRUE)
-      })
-      setwd(old_project)
-      fs::dir_delete(dir)
-    }, envir = env)
-  }
+  withr::defer({
+    ui_silence({
+      proj_set(old_project, force = TRUE)
+    })
+    setwd(old_project)
+    fs::dir_delete(dir)
+  }, envir = env)
 
   ui_silence({
     switch(thing,
@@ -98,6 +86,18 @@ skip_if_no_git_user <- function() {
   skip("No Git user configured")
 }
 
+# CRAN's mac builder sets $HOME to a read-only ram disk, so tests can fail if
+# you even tickle something that might try to lock it's own config file during
+# the operation (e.g. git) or if you simply test for writeability
+skip_on_cran_macos <- function() {
+  sysname <- tolower(Sys.info()[["sysname"]])
+  on_cran <- !identical(Sys.getenv("NOT_CRAN"), "true")
+  if (on_cran && sysname == "darwin") {
+    skip("On CRAN and on macOS")
+  }
+  invisible(TRUE)
+}
+
 expect_usethis_error <- function(...) {
   expect_error(..., class = "usethis_error")
 }
