@@ -1,6 +1,6 @@
 
 test_that("use_description_field() can address an existing field", {
-  pkg <- scoped_temporary_package()
+  pkg <- create_local_package()
   orig <- tools::md5sum(proj_path("DESCRIPTION"))
 
   ## specify existing value of existing field --> should be no op
@@ -31,13 +31,13 @@ test_that("use_description_field() can address an existing field", {
 })
 
 test_that("use_description_field() can add new field", {
-  pkg <- scoped_temporary_package()
+  pkg <- create_local_package()
   use_description_field(name = "foo", value = "bar", base_path = pkg)
   expect_identical(c(foo = "bar"), desc::desc_get("foo", pkg))
 })
 
 test_that("use_description_field() ignores whitespace", {
-  pkg <- scoped_temporary_package()
+  pkg <- create_local_package()
   use_description_field(name = "foo", value = "\n bar")
   use_description_field(name = "foo", value = "bar")
   expect_identical(c(foo = "\n bar"), desc::desc_get("foo", pkg))
@@ -74,7 +74,7 @@ test_that("valid_file_name() enforces valid file names", {
 # use_dependency ----------------------------------------------------------
 
 test_that("we message for new type and are silent for same type", {
-  scoped_temporary_package()
+  create_local_package()
   withr::local_options(list(usethis.quiet = FALSE, crayon.enabled = FALSE))
 
   expect_message(
@@ -85,7 +85,7 @@ test_that("we message for new type and are silent for same type", {
 })
 
 test_that("we message for version change and are silent for same version", {
-  scoped_temporary_package()
+  create_local_package()
   withr::local_options(list(usethis.quiet = FALSE, crayon.enabled = FALSE))
 
   expect_message(
@@ -106,7 +106,7 @@ test_that("we message for version change and are silent for same version", {
 
 ## https://github.com/r-lib/usethis/issues/99
 test_that("use_dependency() upgrades a dependency", {
-  scoped_temporary_package()
+  create_local_package()
   withr::local_options(list(usethis.quiet = FALSE, crayon.enabled = FALSE))
 
   expect_message(use_dependency("usethis", "Suggests"))
@@ -119,7 +119,7 @@ test_that("use_dependency() upgrades a dependency", {
 
 ## https://github.com/r-lib/usethis/issues/99
 test_that("use_dependency() declines to downgrade a dependency", {
-  scoped_temporary_package()
+  create_local_package()
   withr::local_options(list(usethis.quiet = FALSE, crayon.enabled = FALSE))
 
   expect_message(use_dependency("usethis", "Imports"))
@@ -131,7 +131,7 @@ test_that("use_dependency() declines to downgrade a dependency", {
 })
 
 test_that("can add LinkingTo dependency if other dependency already exists", {
-  scoped_temporary_package()
+  create_local_package()
   withr::local_options(list(usethis.quiet = FALSE, crayon.enabled = FALSE))
 
   expect_message(use_dependency("Rcpp", "Imports"), "Adding 'Rcpp'")
