@@ -4,7 +4,7 @@ test_that("use_logo() doesn't error", {
   skip_if_not_installed("magick")
   skip_on_os("solaris")
 
-  pkg <- scoped_temporary_package()
+  pkg <- create_local_package()
   img <- magick::image_write(magick::image_read("logo:"), "logo.png")
   on.exit(file_delete("logo.png"))
 
