@@ -1,14 +1,14 @@
 context("use_pipe")
 
 test_that("use_pipe() requires a package", {
-  scoped_temporary_project()
+  create_local_project()
   expect_usethis_error(use_pipe(), "not an R package")
 })
 
 test_that("use_pipe(export = TRUE) adds promised file, Imports magrittr", {
   with_mock(
     `usethis:::uses_roxygen` = function(base_path) TRUE, {
-      scoped_temporary_package()
+      create_local_package()
       use_pipe(export = TRUE)
       expect_match(desc::desc_get("Imports", proj_get()), "magrittr")
       expect_proj_file("R", "utils-pipe.R")
@@ -19,7 +19,7 @@ test_that("use_pipe(export = TRUE) adds promised file, Imports magrittr", {
 test_that("use_pipe(export = FALSE) adds roxygen to package doc", {
   with_mock(
     `usethis:::uses_roxygen` = function(base_path) TRUE, {
-      scoped_temporary_package()
+      create_local_package()
       use_package_doc()
       use_pipe(export = FALSE)
       expect_match(desc::desc_get("Imports", proj_get()), "magrittr")
@@ -32,7 +32,7 @@ test_that("use_pipe(export = FALSE) adds roxygen to package doc", {
 test_that("use_pipe(export = FALSE) gives advice if no package doc", {
   with_mock(
     `usethis:::uses_roxygen` = function(base_path) TRUE, {
-      scoped_temporary_package()
+      create_local_package()
       withr::local_options(list(usethis.quiet = FALSE))
       expect_message(
         use_pipe(export = FALSE),
