@@ -1,7 +1,7 @@
 context("use_template")
 
 test_that("can leave existing file unchanged, without an error", {
-  scoped_temporary_package()
+  create_local_package()
   desc_lines_before <- read_utf8(proj_path("DESCRIPTION"))
   expect_error_free(
     use_template("NEWS.md", "DESCRIPTION")
