@@ -1,7 +1,7 @@
 context("use_testthat")
 
 test_that("use_testhat() sets up infrastructure", {
-  pkg <- scoped_temporary_package()
+  pkg <- create_local_package()
   use_testthat()
   expect_match(desc::desc_get("Suggests", proj_get()), "testthat")
   expect_proj_dir("tests", "testthat")
